pymcxray package
================

Subpackages
-----------

.. toctree::

    pymcxray.FileFormat
    pymcxray.serialization
    pymcxray.tests

Submodules
----------

pymcxray.AnalyzeNumberBackgroundWindows module
----------------------------------------------

.. automodule:: pymcxray.AnalyzeNumberBackgroundWindows
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.AtomData module
------------------------

.. automodule:: pymcxray.AtomData
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.BatchFile module
-------------------------

.. automodule:: pymcxray.BatchFile
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.BatchFileConsole module
--------------------------------

.. automodule:: pymcxray.BatchFileConsole
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.ComparisonModels module
--------------------------------

.. automodule:: pymcxray.ComparisonModels
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.DebugSimulatedSpectrum module
--------------------------------------

.. automodule:: pymcxray.DebugSimulatedSpectrum
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.ElementProperties module
---------------------------------

.. automodule:: pymcxray.ElementProperties
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.Simulation module
--------------------------

.. automodule:: pymcxray.Simulation
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.SimulationsParameters module
-------------------------------------

.. automodule:: pymcxray.SimulationsParameters
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.Testings module
------------------------

.. automodule:: pymcxray.Testings
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.mcxray module
----------------------

.. automodule:: pymcxray.mcxray
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.multipleloop module
----------------------------

.. automodule:: pymcxray.multipleloop
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.pymcxray module
------------------------

.. automodule:: pymcxray.pymcxray
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.test_AtomData module
-----------------------------

.. automodule:: pymcxray.test_AtomData
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.test_BatchFileConsole module
-------------------------------------

.. automodule:: pymcxray.test_BatchFileConsole
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.test_ComparisonModels module
-------------------------------------

.. automodule:: pymcxray.test_ComparisonModels
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.test_Simulation module
-------------------------------

.. automodule:: pymcxray.test_Simulation
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.test_SimulationsParameters module
------------------------------------------

.. automodule:: pymcxray.test_SimulationsParameters
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.test_mcxray module
---------------------------

.. automodule:: pymcxray.test_mcxray
    :members:
    :undoc-members:
    :show-inheritance:

pymcxray.tests module
---------------------

.. automodule:: pymcxray.tests
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pymcxray
    :members:
    :undoc-members:
    :show-inheritance:
